@@ -1,6 +1,6 @@
 package Org::Element::Block;
 BEGIN {
-  $Org::Element::Block::VERSION = '0.09';
+  $Org::Element::Block::VERSION = '0.10';
 }
 # ABSTRACT: Represent Org block
 
@@ -53,11 +53,11 @@ Org::Element::Block - Represent Org block
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 DESCRIPTION
 
-Derived from Org::Element::Base.
+Derived from L<Org::Element::Base>.
 
 =head1 ATTRIBUTES
 
