@@ -1,6 +1,6 @@
 package Org::Element::Drawer;
 BEGIN {
-  $Org::Element::Drawer::VERSION = '0.09';
+  $Org::Element::Drawer::VERSION = '0.10';
 }
 # ABSTRACT: Represent Org drawer
 
@@ -56,11 +56,11 @@ Org::Element::Drawer - Represent Org drawer
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 DESCRIPTION
 
-Derived from Org::Element::Base.
+Derived from L<Org::Element::Base>.
 
 =head1 ATTRIBUTES
 
