@@ -1,6 +1,6 @@
 package Org::Element::TableVLine;
 BEGIN {
-  $Org::Element::TableVLine::VERSION = '0.09';
+  $Org::Element::TableVLine::VERSION = '0.10';
 }
 # ABSTRACT: Represent Org table vertical line
 
@@ -26,11 +26,11 @@ Org::Element::TableVLine - Represent Org table vertical line
 
 =head1 VERSION
 
-version 0.09
+version 0.10
 
 =head1 DESCRIPTION
 
-Derived from Org::Element::Base.
+Derived from L<Org::Element::Base>.
 
 =head1 ATTRIBUTES
 
